Differentially flat system - kinematic car
------------------------------------------

This example demonstrates the use of the `flatsys` module for
generating trajectories for differentially flat systems.  The example
is drawn from Chapter 8 of FBS2e.

Code
....
.. literalinclude:: kincar-flatsys.py
   :language: python
   :linenos:


Notes
.....
1. The environment variable `PYCONTROL_TEST_EXAMPLES` is used for
testing to turn off plotting of the outputs.
